==> libreoffice_4.0.3.orig.tar.xz: libreoffice-4.0.3.3/forms/source/xforms/boolexpression.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include "boolexpression.hxx"


namespace xforms
{

/** BoolExpression represents a computed XPath expression that returns
 * a bool value and caches the results.
 *
 * As this class has no virtual methods, it should never be used
 * polymorphically. */

BoolExpression::BoolExpression() : ComputedExpression()
{
}

BoolExpression::~BoolExpression()
{
}

void BoolExpression::setExpression( const rtl::OUString& rExpression )
{
    ComputedExpression::setExpression( rExpression );
    mbIsSimple = _checkExpression( " *(true)|(false) *\\( *\\) *" );
}


} // namespace xforms

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-7.1.7.2.tar.xz: libreoffice-7.1.7.2/forms/source/xforms/boolexpression.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "boolexpression.hxx"

namespace xforms
{
/** BoolExpression represents a computed XPath expression that returns
 * a bool value and caches the results.
 *
 * As this class has no virtual methods, it should never be used
 * polymorphically. */

BoolExpression::BoolExpression()
    : ComputedExpression()
{
}

BoolExpression::~BoolExpression() {}

void BoolExpression::setExpression(const OUString& rExpression)
{
    ComputedExpression::setExpression(rExpression);
    mbIsSimple = _checkExpression(" *(true)|(false) *\\( *\\) *");
}

} // namespace xforms

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
